==> esperclient-0.0.12.tar.gz: esperclient-0.0.12/esperclient/models/__init__.py <==
# coding: utf-8

"""
Esper APIs

OpenAPI spec version: 1.0.0
Contact: developer@esper.io
---------------------------------------------------------

Copyright 2019 Shoonya Enterprises Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""



from __future__ import absolute_import

# import models into model package
from esperclient.models.app_install import AppInstall
from esperclient.models.app_install_application import AppInstallApplication
from esperclient.models.app_install_state_enum import AppInstallStateEnum
from esperclient.models.app_install_version import AppInstallVersion
from esperclient.models.app_permission import AppPermission
from esperclient.models.app_version import AppVersion
from esperclient.models.application import Application
from esperclient.models.application_version import ApplicationVersion
from esperclient.models.command_args import CommandArgs
from esperclient.models.command_request import CommandRequest
from esperclient.models.device import Device
from esperclient.models.device_app import DeviceApp
from esperclient.models.device_app_permission import DeviceAppPermission
from esperclient.models.device_command import DeviceCommand
from esperclient.models.device_command_enum import DeviceCommandEnum
from esperclient.models.device_group import DeviceGroup
from esperclient.models.device_group_update import DeviceGroupUpdate
from esperclient.models.device_status import DeviceStatus
from esperclient.models.emm_enterprise_state_enum import EMMEnterpriseStateEnum
from esperclient.models.emm_device import EmmDevice
from esperclient.models.enterprise import Enterprise
from esperclient.models.enterprise_detail import EnterpriseDetail
from esperclient.models.enterprise_update_v1 import EnterpriseUpdateV1
from esperclient.models.enterprise_v1 import EnterpriseV1
from esperclient.models.google_emm import GoogleEMM
from esperclient.models.google_enterprise import GoogleEnterprise
from esperclient.models.group_command import GroupCommand
from esperclient.models.group_command_args import GroupCommandArgs
from esperclient.models.group_command_enum import GroupCommandEnum
from esperclient.models.group_command_request import GroupCommandRequest
from esperclient.models.inline_response200 import InlineResponse200
from esperclient.models.inline_response2001 import InlineResponse2001
from esperclient.models.inline_response2002 import InlineResponse2002
from esperclient.models.inline_response2003 import InlineResponse2003
from esperclient.models.inline_response2004 import InlineResponse2004
from esperclient.models.inline_response2005 import InlineResponse2005
from esperclient.models.inline_response2006 import InlineResponse2006
from esperclient.models.inline_response201 import InlineResponse201
from esperclient.models.settings_gps_state_enum import SettingsGPSStateEnum
from esperclient.models.settings_rotate_state_enum import SettingsRotateStateEnum
from esperclient.models.settings_volume_stream_enum import SettingsVolumeStreamEnum
from esperclient.models.token_info_v1 import TokenInfoV1

==> esperclient-0.0.13.tar.gz: esperclient-0.0.13/esperclient/models/__init__.py <==
# coding: utf-8

"""
Esper APIs

OpenAPI spec version: 1.0.0
Contact: developer@esper.io
---------------------------------------------------------

Copyright 2019 Shoonya Enterprises Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""



from __future__ import absolute_import

# import models into model package
from esperclient.models.app_install import AppInstall
from esperclient.models.app_install_application import AppInstallApplication
from esperclient.models.app_install_state_enum import AppInstallStateEnum
from esperclient.models.app_install_version import AppInstallVersion
from esperclient.models.app_permission import AppPermission
from esperclient.models.app_version import AppVersion
from esperclient.models.application import Application
from esperclient.models.application_version import ApplicationVersion
from esperclient.models.command_args import CommandArgs
from esperclient.models.command_request import CommandRequest
from esperclient.models.device import Device
from esperclient.models.device_app import DeviceApp
from esperclient.models.device_app_permission import DeviceAppPermission
from esperclient.models.device_command import DeviceCommand
from esperclient.models.device_command_enum import DeviceCommandEnum
from esperclient.models.device_group import DeviceGroup
from esperclient.models.device_group_update import DeviceGroupUpdate
from esperclient.models.device_status import DeviceStatus
from esperclient.models.emm_device import EmmDevice
from esperclient.models.enterprise_update_v1 import EnterpriseUpdateV1
from esperclient.models.enterprise_v1 import EnterpriseV1
from esperclient.models.google_emm import GoogleEMM
from esperclient.models.group_command import GroupCommand
from esperclient.models.group_command_args import GroupCommandArgs
from esperclient.models.group_command_enum import GroupCommandEnum
from esperclient.models.group_command_request import GroupCommandRequest
from esperclient.models.inline_response200 import InlineResponse200
from esperclient.models.inline_response2001 import InlineResponse2001
from esperclient.models.inline_response2002 import InlineResponse2002
from esperclient.models.inline_response2003 import InlineResponse2003
from esperclient.models.inline_response2004 import InlineResponse2004
from esperclient.models.inline_response2005 import InlineResponse2005
from esperclient.models.inline_response2006 import InlineResponse2006
from esperclient.models.inline_response2007 import InlineResponse2007
from esperclient.models.inline_response2008 import InlineResponse2008
from esperclient.models.inline_response201 import InlineResponse201
from esperclient.models.settings_gps_state_enum import SettingsGPSStateEnum
from esperclient.models.settings_rotate_state_enum import SettingsRotateStateEnum
from esperclient.models.settings_volume_stream_enum import SettingsVolumeStreamEnum
from esperclient.models.token_info_v1 import TokenInfoV1
from esperclient.models.v0_command_args import V0CommandArgs
from esperclient.models.v0_command_request import V0CommandRequest
from esperclient.models.v0_command_request_status import V0CommandRequestStatus
from esperclient.models.v0_command_schedule_args import V0CommandScheduleArgs
from esperclient.models.v0_command_schedule_args_time_type_enum import V0CommandScheduleArgsTimeTypeEnum
from esperclient.models.v0_command_schedule_enum import V0CommandScheduleEnum
from esperclient.models.v0_command_status import V0CommandStatus
from esperclient.models.v0_command_status_update import V0CommandStatusUpdate
from esperclient.models.v0_command_status_update_details import V0CommandStatusUpdateDetails
from esperclient.models.v0_device_command_enum import V0DeviceCommandEnum
